## infestor

<img src="https://steemitimages.com/p/C3TZR1g81UNaPs7vzNXHueW5ZM76DSHWEY7onmfLxcK2iPZP7xUgX7ew6iQA4kLF9kUR6ZUFws35JpoWaXbCP13VMZpme1gd1TwaNwuJdLF4VdytcNVvhdx?format=match&mode=fit">

infestor is a cross platform CLI app to claim and create
discounted accounts on the STEEM blockchain.

## Installation

```
$ pip install infestor
```

## Claiming discounted accounts

```
$ infestor claim_account --creator <your_account>
```

## Creating accounts

```
$ infestor create_claimed_account --new-account-name <your_new_account> --creator <your_main_account>
```

